@@ -1,9 +1,10 @@
 
-/* A Bison parser, made by GNU Bison 2.3b.  */
+/* A Bison parser, made by GNU Bison 2.4.  */
 
 /* Skeleton implementation for Bison LALR(1) parsers in C++
    
-      Copyright (C) 2002, 2003, 2004, 2005, 2006 Free Software Foundation, Inc.
+      Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008 Free Software
+   Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -35,8 +36,8 @@
 /* First part of user declarations.  */
 
 
-/* Line 309 of lalr1.cc  */
-#line 40 "./calc++-parser.cc"
+/* Line 311 of lalr1.cc  */
+#line 41 "./calc++-parser.cc"
 
 
 #include "calc++-parser.hh"
@@ -44,19 +45,19 @@
 /* User implementation prologue.  */
 
 
-/* Line 315 of lalr1.cc  */
-#line 49 "./calc++-parser.cc"
+/* Line 317 of lalr1.cc  */
+#line 50 "./calc++-parser.cc"
 /* Unqualified %code blocks.  */
 
-/* Line 316 of lalr1.cc  */
-#line 8493 "../../doc/bison.texinfo"
+/* Line 318 of lalr1.cc  */
+#line 8501 "../../doc/bison.texinfo"
 
 # include "calc++-driver.hh"
 
 
 
-/* Line 316 of lalr1.cc  */
-#line 60 "./calc++-parser.cc"
+/* Line 318 of lalr1.cc  */
+#line 61 "./calc++-parser.cc"
 
 #ifndef YY_
 # if YYENABLE_NLS
@@ -110,18 +111,22 @@ do {					\
 
 #endif /* !YYDEBUG */
 
+#define yyerrok		(yyerrstatus_ = 0)
+#define yyclearin	(yychar = yyempty_)
+
 #define YYACCEPT	goto yyacceptlab
 #define YYABORT		goto yyabortlab
 #define YYERROR		goto yyerrorlab
+#define YYRECOVERING()  (!!yyerrstatus_)
 
 
-/* Line 374 of lalr1.cc  */
+/* Line 380 of lalr1.cc  */
 #line 1 "[Bison:b4_percent_define_default]"
 
 namespace yy {
 
-/* Line 374 of lalr1.cc  */
-#line 125 "./calc++-parser.cc"
+/* Line 380 of lalr1.cc  */
+#line 130 "./calc++-parser.cc"
 #if YYERROR_VERBOSE
 
   /* Return YYSTR after stripping away unnecessary quotes and
@@ -193,30 +198,30 @@ namespace yy {
       {
         case 4: /* "\"identifier\"" */
 
-/* Line 443 of lalr1.cc  */
-#line 8522 "../../doc/bison.texinfo"
+/* Line 449 of lalr1.cc  */
+#line 8530 "../../doc/bison.texinfo"
 	{ debug_stream () << *(yyvaluep->sval); };
 
-/* Line 443 of lalr1.cc  */
-#line 202 "./calc++-parser.cc"
+/* Line 449 of lalr1.cc  */
+#line 207 "./calc++-parser.cc"
 	break;
       case 5: /* "\"number\"" */
 
-/* Line 443 of lalr1.cc  */
-#line 8525 "../../doc/bison.texinfo"
+/* Line 449 of lalr1.cc  */
+#line 8533 "../../doc/bison.texinfo"
 	{ debug_stream () << (yyvaluep->ival); };
 
-/* Line 443 of lalr1.cc  */
-#line 211 "./calc++-parser.cc"
+/* Line 449 of lalr1.cc  */
+#line 216 "./calc++-parser.cc"
 	break;
       case 14: /* "exp" */
 
-/* Line 443 of lalr1.cc  */
-#line 8525 "../../doc/bison.texinfo"
+/* Line 449 of lalr1.cc  */
+#line 8533 "../../doc/bison.texinfo"
 	{ debug_stream () << (yyvaluep->ival); };
 
-/* Line 443 of lalr1.cc  */
-#line 220 "./calc++-parser.cc"
+/* Line 449 of lalr1.cc  */
+#line 225 "./calc++-parser.cc"
 	break;
        default:
 	  break;
@@ -250,12 +255,12 @@ namespace yy {
       {
         case 4: /* "\"identifier\"" */
 
-/* Line 474 of lalr1.cc  */
-#line 8523 "../../doc/bison.texinfo"
+/* Line 480 of lalr1.cc  */
+#line 8531 "../../doc/bison.texinfo"
 	{ delete (yyvaluep->sval); };
 
-/* Line 474 of lalr1.cc  */
-#line 259 "./calc++-parser.cc"
+/* Line 480 of lalr1.cc  */
+#line 264 "./calc++-parser.cc"
 	break;
 
 	default:
@@ -319,7 +324,7 @@ namespace yy {
     /// Location of the lookahead.
     location_type yylloc;
     /// The locations where the error started and ended.
-    location yyerror_range[2];
+    location_type yyerror_range[2];
 
     /// $$.
     semantic_type yyval;
@@ -333,15 +338,15 @@ namespace yy {
 
     /* User initialization code.  */
     
-/* Line 547 of lalr1.cc  */
-#line 8456 "../../doc/bison.texinfo"
+/* Line 559 of lalr1.cc  */
+#line 8464 "../../doc/bison.texinfo"
 {
   // Initialize the initial location.
   yylloc.begin.filename = yylloc.end.filename = &driver.file;
 }
 
-/* Line 547 of lalr1.cc  */
-#line 345 "./calc++-parser.cc"
+/* Line 559 of lalr1.cc  */
+#line 350 "./calc++-parser.cc"
 
     /* Initialize the stacks.  The initial state will be pushed in
        yynewstate, since the latter expects the semantical and the
@@ -459,79 +464,80 @@ namespace yy {
       {
 	  case 2:
 
-/* Line 672 of lalr1.cc  */
-#line 8535 "../../doc/bison.texinfo"
+/* Line 678 of lalr1.cc  */
+#line 8543 "../../doc/bison.texinfo"
     { driver.result = (yysemantic_stack_[(2) - (2)].ival); }
     break;
 
   case 3:
 
-/* Line 672 of lalr1.cc  */
-#line 8537 "../../doc/bison.texinfo"
+/* Line 678 of lalr1.cc  */
+#line 8545 "../../doc/bison.texinfo"
     {}
     break;
 
   case 4:
 
-/* Line 672 of lalr1.cc  */
-#line 8538 "../../doc/bison.texinfo"
+/* Line 678 of lalr1.cc  */
+#line 8546 "../../doc/bison.texinfo"
     {}
     break;
 
   case 5:
 
-/* Line 672 of lalr1.cc  */
-#line 8542 "../../doc/bison.texinfo"
+/* Line 678 of lalr1.cc  */
+#line 8550 "../../doc/bison.texinfo"
     { driver.variables[*(yysemantic_stack_[(3) - (1)].sval)] = (yysemantic_stack_[(3) - (3)].ival); delete (yysemantic_stack_[(3) - (1)].sval); }
     break;
 
   case 6:
 
-/* Line 672 of lalr1.cc  */
-#line 8546 "../../doc/bison.texinfo"
+/* Line 678 of lalr1.cc  */
+#line 8554 "../../doc/bison.texinfo"
     { (yyval.ival) = (yysemantic_stack_[(3) - (1)].ival) + (yysemantic_stack_[(3) - (3)].ival); }
     break;
 
   case 7:
 
-/* Line 672 of lalr1.cc  */
-#line 8547 "../../doc/bison.texinfo"
+/* Line 678 of lalr1.cc  */
+#line 8555 "../../doc/bison.texinfo"
     { (yyval.ival) = (yysemantic_stack_[(3) - (1)].ival) - (yysemantic_stack_[(3) - (3)].ival); }
     break;
 
   case 8:
 
-/* Line 672 of lalr1.cc  */
-#line 8548 "../../doc/bison.texinfo"
+/* Line 678 of lalr1.cc  */
+#line 8556 "../../doc/bison.texinfo"
     { (yyval.ival) = (yysemantic_stack_[(3) - (1)].ival) * (yysemantic_stack_[(3) - (3)].ival); }
     break;
 
   case 9:
 
-/* Line 672 of lalr1.cc  */
-#line 8549 "../../doc/bison.texinfo"
+/* Line 678 of lalr1.cc  */
+#line 8557 "../../doc/bison.texinfo"
     { (yyval.ival) = (yysemantic_stack_[(3) - (1)].ival) / (yysemantic_stack_[(3) - (3)].ival); }
     break;
 
   case 10:
 
-/* Line 672 of lalr1.cc  */
-#line 8550 "../../doc/bison.texinfo"
+/* Line 678 of lalr1.cc  */
+#line 8558 "../../doc/bison.texinfo"
     { (yyval.ival) = driver.variables[*(yysemantic_stack_[(1) - (1)].sval)]; delete (yysemantic_stack_[(1) - (1)].sval); }
     break;
 
   case 11:
 
-/* Line 672 of lalr1.cc  */
-#line 8551 "../../doc/bison.texinfo"
+/* Line 678 of lalr1.cc  */
+#line 8559 "../../doc/bison.texinfo"
     { (yyval.ival) = (yysemantic_stack_[(1) - (1)].ival); }
     break;
 
 
 
-/* Line 672 of lalr1.cc  */
-#line 534 "./calc++-parser.cc"
-	default: break;
+/* Line 678 of lalr1.cc  */
+#line 539 "./calc++-parser.cc"
+	default:
+          break;
       }
     YY_SYMBOL_PRINT ("-> $$ =", yyr1_[yyn], &yyval, &yyloc);
 
@@ -648,7 +654,7 @@ namespace yy {
 
     /* Shift the error token.  */
     YY_SYMBOL_PRINT ("Shifting", yystos_[yyn],
-		   &yysemantic_stack_[0], &yylocation_stack_[0]);
+		     &yysemantic_stack_[0], &yylocation_stack_[0]);
 
     yystate = yyn;
     goto yynewstate;
@@ -856,8 +862,8 @@ namespace yy {
   const unsigned short int
   calcxx_parser::yyrline_[] =
   {
-         0,  8535,  8535,  8537,  8538,  8541,  8546,  8547,  8548,  8549,
-    8550,  8551
+         0,  8543,  8543,  8545,  8546,  8549,  8554,  8555,  8556,  8557,
+    8558,  8559
   };
 
   // Print the state stack on the debug stream.
@@ -944,19 +950,19 @@ namespace yy {
   const calcxx_parser::token_number_type calcxx_parser::yyundef_token_ = 2;
 
 
-/* Line 1047 of lalr1.cc  */
+/* Line 1054 of lalr1.cc  */
 #line 1 "[Bison:b4_percent_define_default]"
 
 } // yy
 
-/* Line 1047 of lalr1.cc  */
-#line 954 "./calc++-parser.cc"
+/* Line 1054 of lalr1.cc  */
+#line 960 "./calc++-parser.cc"
 
 
-/* Line 1049 of lalr1.cc  */
-#line 8552 "../../doc/bison.texinfo"
+/* Line 1056 of lalr1.cc  */
+#line 8560 "../../doc/bison.texinfo"
 
-#line 8561 "../../doc/bison.texinfo"
+#line 8569 "../../doc/bison.texinfo"
 void
 yy::calcxx_parser::error (const yy::calcxx_parser::location_type& l,
                           const std::string& m)
